@@ -354,13 +354,13 @@ class OpticalDataset:
         aod_to_ground = self.a[min_alpha_idx] * (self.z[min_alpha_idx] - self.z0)
 
         if (self.z[min_alpha_idx] - self.z0) > 1000:
-            print "Warning: The min altitude is %s. Interpolation to the ground could be wrong." % self.z[0]
+            print("Warning: The min altitude is %s. Interpolation to the ground could be wrong." % self.z[0])
 
         difs = list(set(np.diff(self.z)))
         difs.sort()
         if len(difs) > 2:
-            print "Warning: Irregular altitude range. len(set(diffs)): %s " % len(difs)
-            print difs
+            print("Warning: Irregular altitude range. len(set(diffs)): %s " % len(difs))
+            print(difs)
 
         if abs(difs[0] - 60) > 5:
             raise ValueError("Strange altitude difference. Check manually. Difs[0] %s " % difs[0])
